@@ -3,12 +3,12 @@ var indexSectionsWithContent =
   0: "acdefghilmnoprstuvw▶✅🎪🎯📌📚🔢🔧🔨🛡🧩",
   1: "cfglmostu",
   2: "acefhimstw",
-  3: "fipruv",
+  3: "cfipruv",
   4: "csu",
   5: "cu",
   6: "c",
   7: "acdimoprstuv▶✅🎪🎯📌📚🔢🔧🔨🛡🧩",
-  8: "acdefilmnoprstuv"
+  8: "acdefilmnoprstuvw"
 };
 
 var indexSectionNames =
